An internal function for sending http requests to the US Census Bureau TIGER api via httr::GET() function.
.send_tiger_url(
a_url = NULL,
output_dir = NULL,
delete_files = TRUE,
set_crs = NULL,
transform_crs = NULL,
sf_info = FALSE,
do_progress = FALSE,
caller = NULL
)A data frame object of class sf, data frame
A required string that defines the url to be sent in the http GET request.
A full directory path where the shapefile and its associated files will be downloaded.
A logical which if TRUE will delete the shapefile and associated files in 'output_dir'.
The default is TRUE.
A numeric or character string which if non-NULL calls sf::st_crs() to set the crs of the geometries.
A numeric or character string which if non-NULL calls sf::st_transform()
to perform a crs transform of the geometries.
A logical which if TRUE displays info on the resulting simple feature object.
A logical which if TRUE displays a progress bar during the download.
A string that identifies the function making the call.