| .send_tiger_url | R Documentation |
An internal function for sending http requests to the US Census Bureau TIGER api via httr::GET() function.
.send_tiger_url(
a_url = NULL,
output_dir = NULL,
delete_files = TRUE,
set_crs = NULL,
transform_crs = NULL,
sf_info = FALSE,
do_progress = FALSE,
caller = NULL
)
a_url |
A required string that defines the url to be sent in the http GET request. |
output_dir |
A full directory path where the shapefile and its associated files will be downloaded. |
delete_files |
A logical which if |
set_crs |
A numeric or character string which if non-NULL calls |
transform_crs |
A numeric or character string which if non-NULL calls |
sf_info |
A logical which if |
do_progress |
A logical which if |
caller |
A string that identifies the function making the call. |
A data frame object of class sf, data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.