Returns simple feature (sf) of US Census block boundary related geometric polygons,
provided by the US Census Bureau's TIGER/Line Shapefiles database. See
Simple Features for R
for more information on simple features. Along with the geometries, additional block related
variables are provided. See Appendix G-1. Record Layout: Block State-based Shapefile)
for a description of block related variables of the sf file. For further information on the Census Bureau's shape files see
About the 2021 TIGER/Line Shapefiles.
From Chapter 4.2 Blocks --
"Census blocks are statistical areas bounded on all sides by visible features (e.g., streets, roads, streams,
and railroad tracks), and by non-visible boundaries (e.g., city, town, township, county limits, and short
line-of-sight extensions of streets and roads)."
The function returns the simple feature object which can easily be mapped (see RplotterPkg::create_sf_plot()) or
joined with US Census Bureau demographic data via the GEOID value. Be aware that shapefiles for blocks can
be very large and time consuming to download for some states.
Some earlier vintages may have NA for the crs so you may need to specify the crs_transform to 3426. Also
you may be interested in using a state level crs. See epsg.io to search worldwide for crs.