- output_dir
A full directory path where the shapefile and its associated files will be downloaded.
The default is the directory defined by the value returned by tempdir().
- delete_files
A logical which if TRUE will delete the shapefile and associated files in 'output_dir'.
The default is TRUE.
- vintage
A numeric that sets the vintage of interest. The default is 2020.
- general
A logical which if TRUE will download a less detailed, more generalized version of the county geometries.
- resol
If 'general' is TRUE, then the resolution to return. Acceptable values are strings
"500k", "5m", "20m".
- set_crs
A numeric or character string which if non-NULL calls sf::st_crs() to set the crs of the geometries and transforms them.
- transform_crs
A numeric or character string which if non-NULL calls sf::st_transform()
to perform a crs transform of the geometries. Note that the crs of the shapefile must not be NA.
- sf_info
A logical which if TRUE displays info on the resulting simple feature object.
- do_progress
A logical which if TRUE displays a progress bar during the download.
- shapefile
A full file path to a shapefile folder with its unzipped files to be processed instead of downloading.
- datafile
A dataframe containing data that should be joined with this function's resultant simple feature object.
- datafile_key
The column name from 'datafile' dataframe used to key with the 'sf_key' column
of the resultant simple feature dataframe.
- sf_key
The column from the resultant dataframe used to key with the 'datafile' dataframe.
- express
A logical expression object used to filter the resultant simple feature dataframe.
For example, one of the columns of the resultant simple feature dataframe is "STATEFP".
If you wanted to return just the geometries for Florida (which has a fips code of "12"),
then you assign 'express' equal to: expression(STATEFP == "12"). The expression will be
evaluated and only the geometries for Florida will be returned.
- check_na
A logical which if TRUE will remove rows that have missing values for any of the columns.
The default is to not check the columns for NA values.