- state
The required two-digit FIPS code for the state of interest.
See usmap::fips function for finding FIPS codes.
- output_dir
A full directory path where the shapefile and its associated files will be downloaded.
The default is the directory defined by the value returned by tempdir().
- delete_files
A logical which if TRUE will delete the shapefile and associated files in 'output_dir'.
The default is TRUE.
- vintage
A numeric that sets the vintage of interest. The default is 2020.
The value should be greater than 2010.
- entity
A character string that sets the specific landmark entity of interest. The
acceptable values are "area" or "point". The default is "point".
- set_crs
A numeric or character string which if non-NULL calls sf::st_crs() to set the crs of the geometries and transforms them.
- transform_crs
A numeric or character string which if non-NULL calls sf::st_transform()
to perform a crs transform of the geometries. Note that the crs of the shapefile must not be NA.
- sf_info
A logical which if TRUE displays info on the resulting simple feature object.
- do_progress
A logical which if TRUE displays a progress bar during the download.
- shapefile
A full file path to a shapefile folder with its unzipped files to be processed instead of downloading.
- express
A logical expression object used to filter the resultant simple feature dataframe.
For example, one of the columns of the resultant simple feature dataframe is "STATEFP".
If you wanted to return just the geometries for Nelson County, Kentucky (which has a fips code of "179"),
then you assign 'express' equal to: expression(COUNTYFP == "179"). The expression will be
evaluated and only the landmark geometries for Nelson County will be returned.
- check_na
A logical which if TRUE will remove rows that have missing values for any of the columns.
The default is to not check the columns for NA values.
Note: Vintage must be greater than 2010.