Returns simple feature (sf) of state boundary related geometric polygons,
provided by the US Census Bureau's TIGER/Line Shapefiles database. See
Simple Features for R
for more information on simple features. Along with the geometries, additional state related
variables are provided. See Appendix P-5. Record Layout: State and Equivalent Entity National Shapefile)
for a description of state related variables of the sf file. For further information on the Census Bureau's shape files see
About the 2021 TIGER/Line Shapefiles.
From Chapter 4.17 States and State Equivalent Entities --
"States and equivalent entities are the primary governmental divisions of the United States. In addition to
the fifty states, the Census Bureau treats the District of Columbia, Puerto Rico, and the Island Areas
(American Samoa, the Commonwealth of the Northern Mariana Islands, Guam, and the U.S. Virgin
Islands) as statistical equivalents of states for the purpose of data presentation."
A more generalized, recognizable version of the state geometries that has less download size is also available. For more information on cartographic boundary files see
Cartographic Boundary File Description.
These files are available for vintages greater than 2013 with resolution 1:500k, 1:5m, 1:20m meters.
The function returns the simple feature object which can easily be mapped (see RplotterPkg::create_sf_plot()) or
joined with US Census Bureau demographic data. To help incorporate data files, this function
has a 'datafile' parameter which will be joined with the resultant simple feature object. The only
requirement is that a common "key" for joining exist between the data dataframe and the simple feature dataframe.
Some earlier vintages may have NA for the crs so you may need to specify the 'crs_transform' to 3426. Also
you may be interested in using a state level crs. See epsg.io to search worldwide for crs.