Description
An internal function that creates the base url
address to be submitted as a http GET request by .get_dt.
It initializes with the dataset name and optionally the vintage.
Usage
.get_url(dataset, vintage)
Value
Returns a url string.
Arguments
- dataset
A string that sets the name of the data set of interest (e.g. "acs/acs5").
This is a required parameter.
- vintage
An optional numeric that sets the vintage of interest.